@@ -41,6 +41,7 @@ from firewall.server.decorators import handle_exceptions, \
     dbus_handle_exceptions, dbus_service_method
 from firewall import errors
 from firewall.errors import FirewallError
+from firewall.functions import portInPortRange
 
 ############################################################################
 #
@@ -483,7 +484,15 @@ class FirewallDConfigZone(slip.dbus.service.Object):
         protocol = dbus_to_python(protocol, str)
         log.debug1("%s.queryPort('%s', '%s')", self._log_prefix, port,
                    protocol)
-        return (port,protocol) in self.getSettings()[6]
+        if (port,protocol) in self.getSettings()[6]:
+            return True
+        else:
+            # It might be a single port query that is inside a range
+            for (_port, _protocol) in self.getSettings()[6]:
+                if portInPortRange(port, _port) and protocol == _protocol:
+                    return True
+
+        return False
 
     # protocol
 
